==> paper-masked-input-2.0.2.jar: META-INF/resources/webjars/paper-masked-input/CHANGELOG.md <==
<a name="2.0.2"></a>
## [2.0.2](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...2.0.2) (2018-03-18)


### Docs

* Updated documentation page for webcomponents.org ([6b04065050af8a9035ba0cbb492159867c531232](https://github.com/advanced-rest-client/paper-masked-input/commit/6b04065050af8a9035ba0cbb492159867c531232))

### Fix

* Fixed validation function ([9eab807e0612f4221668f914b516715e2d1b4a95](https://github.com/advanced-rest-client/paper-masked-input/commit/9eab807e0612f4221668f914b516715e2d1b4a95))

### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated component to Polymer 2.0 ([2fad928c47987bc18e356c306f05f04879658968](https://github.com/advanced-rest-client/paper-masked-input/commit/2fad928c47987bc18e356c306f05f04879658968))
* Updated component to Polymer 2.0 ([ac35d431eff8bad4887a9daaa9f0b6a0ba036406](https://github.com/advanced-rest-client/paper-masked-input/commit/ac35d431eff8bad4887a9daaa9f0b6a0ba036406))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="2.0.1"></a>
## [2.0.1](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...2.0.1) (2018-03-18)


### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated component to Polymer 2.0 ([2fad928c47987bc18e356c306f05f04879658968](https://github.com/advanced-rest-client/paper-masked-input/commit/2fad928c47987bc18e356c306f05f04879658968))
* Updated component to Polymer 2.0 ([ac35d431eff8bad4887a9daaa9f0b6a0ba036406](https://github.com/advanced-rest-client/paper-masked-input/commit/ac35d431eff8bad4887a9daaa9f0b6a0ba036406))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="1.0.7"></a>
## [1.0.7](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...v1.0.7) (2017-07-13)


### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="1.0.6"></a>
## [1.0.6](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.5...v1.0.6) (2016-11-21)


### Update

* Added new Travis configuration ([deb0e3439b750ce3b67df715f7c95507491aee92](https://github.com/advanced-rest-client/paper-masked-input/commit/deb0e3439b750ce3b67df715f7c95507491aee92))

==> paper-masked-input-2.0.3.jar: META-INF/resources/webjars/paper-masked-input/CHANGELOG.md <==
<a name="2.0.3"></a>
## [2.0.3](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...2.0.3) (2018-06-19)


### Docs

* Updated documentation page for webcomponents.org ([6b04065050af8a9035ba0cbb492159867c531232](https://github.com/advanced-rest-client/paper-masked-input/commit/6b04065050af8a9035ba0cbb492159867c531232))

### Fix

* Fixed validation function ([9eab807e0612f4221668f914b516715e2d1b4a95](https://github.com/advanced-rest-client/paper-masked-input/commit/9eab807e0612f4221668f914b516715e2d1b4a95))

### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated component to Polymer 2.0 ([2fad928c47987bc18e356c306f05f04879658968](https://github.com/advanced-rest-client/paper-masked-input/commit/2fad928c47987bc18e356c306f05f04879658968))
* Updated component to Polymer 2.0 ([ac35d431eff8bad4887a9daaa9f0b6a0ba036406](https://github.com/advanced-rest-client/paper-masked-input/commit/ac35d431eff8bad4887a9daaa9f0b6a0ba036406))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="2.0.2"></a>
## [2.0.2](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...2.0.2) (2018-03-18)


### Docs

* Updated documentation page for webcomponents.org ([6b04065050af8a9035ba0cbb492159867c531232](https://github.com/advanced-rest-client/paper-masked-input/commit/6b04065050af8a9035ba0cbb492159867c531232))

### Fix

* Fixed validation function ([9eab807e0612f4221668f914b516715e2d1b4a95](https://github.com/advanced-rest-client/paper-masked-input/commit/9eab807e0612f4221668f914b516715e2d1b4a95))

### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated component to Polymer 2.0 ([2fad928c47987bc18e356c306f05f04879658968](https://github.com/advanced-rest-client/paper-masked-input/commit/2fad928c47987bc18e356c306f05f04879658968))
* Updated component to Polymer 2.0 ([ac35d431eff8bad4887a9daaa9f0b6a0ba036406](https://github.com/advanced-rest-client/paper-masked-input/commit/ac35d431eff8bad4887a9daaa9f0b6a0ba036406))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="2.0.1"></a>
## [2.0.1](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...2.0.1) (2018-03-18)


### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated component to Polymer 2.0 ([2fad928c47987bc18e356c306f05f04879658968](https://github.com/advanced-rest-client/paper-masked-input/commit/2fad928c47987bc18e356c306f05f04879658968))
* Updated component to Polymer 2.0 ([ac35d431eff8bad4887a9daaa9f0b6a0ba036406](https://github.com/advanced-rest-client/paper-masked-input/commit/ac35d431eff8bad4887a9daaa9f0b6a0ba036406))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="1.0.7"></a>
## [1.0.7](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.6...v1.0.7) (2017-07-13)


### Update

* Removed external jscript file and added JS code to the element definition. ([6dd547d7de687c93abff052bde2bc03cd3f1e462](https://github.com/advanced-rest-client/paper-masked-input/commit/6dd547d7de687c93abff052bde2bc03cd3f1e462))
* removed focus from the element and moved it to the input. Simplified computations. ([bdb7dfd7faf2de841ce27c76d32a64d1eb444945](https://github.com/advanced-rest-client/paper-masked-input/commit/bdb7dfd7faf2de841ce27c76d32a64d1eb444945))
* Removed unused file. ([301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1](https://github.com/advanced-rest-client/paper-masked-input/commit/301c2d8fe7213f423f7477fcc42f2f1e7ae4c4e1))
* Updated resolutions for a component ([b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba](https://github.com/advanced-rest-client/paper-masked-input/commit/b3b63243ccd0e0b7092b9b8c6b0d1e0a817358ba))
* Updated test and demo pages dependencies. ([bc80bd39f318f7f65b02ec3184b679ed3ead9376](https://github.com/advanced-rest-client/paper-masked-input/commit/bc80bd39f318f7f65b02ec3184b679ed3ead9376))
* Updated test and tests configuration. ([2188b83df72d0f21ecd85f04791aebc28ec1c58c](https://github.com/advanced-rest-client/paper-masked-input/commit/2188b83df72d0f21ecd85f04791aebc28ec1c58c))



<a name="1.0.6"></a>
## [1.0.6](https://github.com/advanced-rest-client/paper-masked-input/compare/1.0.5...v1.0.6) (2016-11-21)


### Update

* Added new Travis configuration ([deb0e3439b750ce3b67df715f7c95507491aee92](https://github.com/advanced-rest-client/paper-masked-input/commit/deb0e3439b750ce3b67df715f7c95507491aee92))
